changeset 336:84d5af1e2619

/!\ package is being renamed to libervia-templates following global name change /!\
author Goffi <goffi@goffi.org>
date Fri, 18 Jun 2021 15:52:37 +0200
parents 11d138c52628
children f75f8952dac8
files setup.py
diffstat 1 files changed, 8 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/setup.py	Tue Jun 15 13:43:54 2021 +0000
+++ b/setup.py	Fri Jun 18 15:52:37 2021 +0200
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
 # SàT templates: collection of templates
 # Copyright (C) 2017-2021  Jérôme Poisson (goffi@goffi.org)
 # Copyright (C) 2017  Xavier Maillard (xavier@maillard.im)
 
@@ -20,10 +20,13 @@
 import os
 from setuptools import setup, find_packages
 
-NAME = "sat_templates"
+NAME = "libervia-templates"
+# NOTE: directory is still "sat_templates" for compatibility reason,
+#   should be changed for 0.9
+DIR_NAME = "sat_templates"
 
 
-with open(os.path.join(NAME, "VERSION")) as f:
+with open(os.path.join(DIR_NAME, "VERSION")) as f:
     VERSION = f.read().strip()
 is_dev_version = VERSION.endswith("D")
 
@@ -45,7 +48,7 @@
 setup_info = dict(
     name=NAME,
     version=VERSION,
-    description="Templates for Salut à Toi XMPP client",
+    description="Templates for Libervia XMPP client",
     long_description="SàT Template is a common module which can be used by any SàT "
                      "frontend to generate documents (mostly HTML but not only).",
     author="Association « Salut à Toi »",
@@ -55,6 +58,7 @@
         "Programming Language :: Python :: 3 :: Only",
         "Programming Language :: Python :: 3.7",
         "Programming Language :: Python :: 3.8",
+        "Programming Language :: Python :: 3.9",
         "Development Status :: 5 - Production/Stable",
         "License :: OSI Approved :: GNU Affero General Public License v3 or later "
         "(AGPLv3+)",
@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# SàT templates: collection of templates
+# Libervia templates: collection of templates
 # Copyright (C) 2017-2021  Jérôme Poisson (goffi@goffi.org)
 # Copyright (C) 2017  Xavier Maillard (xavier@maillard.im)